@@ -1,5 +1,3 @@
-package org.eclipse.aether.repository;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.repository;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,21 +16,20 @@ package org.eclipse.aether.repository;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.repository;
 
 /**
  * Selects a proxy for a given remote repository.
- * 
+ *
  * @see org.eclipse.aether.RepositorySystemSession#getProxySelector()
  */
-public interface ProxySelector
-{
+public interface ProxySelector {
 
     /**
      * Selects a proxy for the specified remote repository.
-     * 
+     *
      * @param repository The repository for which to select a proxy, must not be {@code null}.
      * @return The selected proxy or {@code null} if none.
      */
-    Proxy getProxy( RemoteRepository repository );
-
+    Proxy getProxy(RemoteRepository repository);
 }
