@@ -24,7 +24,9 @@ import java.util.Collections;
 import org.eclipse.aether.artifact.DefaultArtifact;
 import org.junit.Test;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertSame;
 
 /**
  */
