@@ -1,5 +1,3 @@
-package org.eclipse.aether.internal.impl;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.internal.impl;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +16,7 @@ package org.eclipse.aether.internal.impl;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.internal.impl;
 
 import javax.inject.Inject;
 import javax.inject.Named;
@@ -31,17 +30,13 @@ import org.eclipse.aether.spi.log.LoggerFactory;
  */
 @Named
 @Singleton
-public class LoggerFactoryProvider
-    implements Provider<LoggerFactory>
-{
+public class LoggerFactoryProvider implements Provider<LoggerFactory> {
 
     @Inject
-    @Named( "slf4j" )
+    @Named("slf4j")
     private Provider<LoggerFactory> slf4j;
 
-    public LoggerFactory get()
-    {
-            return slf4j.get();
+    public LoggerFactory get() {
+        return slf4j.get();
     }
-
 }
