@@ -1,5 +1,3 @@
-package org.eclipse.aether.transport.http;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.transport.http;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +16,7 @@ package org.eclipse.aether.transport.http;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.transport.http;
 
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -29,56 +28,42 @@ import org.apache.http.client.utils.URIUtils;
 /**
  * Helps to deal with URIs.
  */
-final class UriUtils
-{
+final class UriUtils {
 
-    public static URI resolve( URI base, URI ref )
-    {
+    public static URI resolve(URI base, URI ref) {
         String path = ref.getRawPath();
-        if ( path != null && path.length() > 0 )
-        {
+        if (path != null && path.length() > 0) {
             path = base.getRawPath();
-            if ( path == null || !path.endsWith( "/" ) )
-            {
-                try
-                {
-                    base = new URI( base.getScheme(), base.getAuthority(), base.getPath() + '/', null, null );
-                }
-                catch ( URISyntaxException e )
-                {
-                    throw new IllegalStateException( e );
+            if (path == null || !path.endsWith("/")) {
+                try {
+                    base = new URI(base.getScheme(), base.getAuthority(), base.getPath() + '/', null, null);
+                } catch (URISyntaxException e) {
+                    throw new IllegalStateException(e);
                 }
             }
         }
-        return URIUtils.resolve( base, ref );
+        return URIUtils.resolve(base, ref);
     }
 
-    public static List<URI> getDirectories( URI base, URI uri )
-    {
+    public static List<URI> getDirectories(URI base, URI uri) {
         List<URI> dirs = new ArrayList<>();
-        for ( URI dir = uri.resolve( "." ); !isBase( base, dir ); dir = dir.resolve( ".." ) )
-        {
-            dirs.add( dir );
+        for (URI dir = uri.resolve("."); !isBase(base, dir); dir = dir.resolve("..")) {
+            dirs.add(dir);
         }
         return dirs;
     }
 
-    private static boolean isBase( URI base, URI uri )
-    {
+    private static boolean isBase(URI base, URI uri) {
         String path = uri.getRawPath();
-        if ( path == null || "/".equals( path ) )
-        {
+        if (path == null || "/".equals(path)) {
             return true;
         }
-        if ( base != null )
-        {
-            URI rel = base.relativize( uri );
-            if ( rel.getRawPath() == null || rel.getRawPath().length() <= 0 || rel.equals( uri ) )
-            {
+        if (base != null) {
+            URI rel = base.relativize(uri);
+            if (rel.getRawPath() == null || rel.getRawPath().isEmpty() || rel.equals(uri)) {
                 return true;
             }
         }
         return false;
     }
-
 }
