@@ -1,5 +1,3 @@
-package org.eclipse.aether.util.artifact;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -8,9 +6,9 @@ package org.eclipse.aether.util.artifact;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
- *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,23 +16,22 @@ package org.eclipse.aether.util.artifact;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.eclipse.aether.util.artifact;
 
 import java.io.File;
 import java.util.Map;
 import java.util.Objects;
 
-import static java.util.Objects.requireNonNull;
-
 import org.eclipse.aether.artifact.AbstractArtifact;
 import org.eclipse.aether.artifact.Artifact;
 
+import static java.util.Objects.requireNonNull;
+
 /**
  * An artifact whose identity is derived from another artifact. <em>Note:</em> Instances of this class are immutable and
  * the exposed mutators return new objects rather than changing the current instance.
  */
-public final class SubArtifact
-    extends AbstractArtifact
-{
+public final class SubArtifact extends AbstractArtifact {
 
     private final Artifact mainArtifact;
 
@@ -51,14 +48,13 @@ public final class SubArtifact
      * character "*" to refer to the corresponding property of the main artifact. For instance, the classifier
      * "*-sources" can be used to refer to the source attachment of an artifact. Likewise, the extension "*.asc" can be
      * used to refer to the GPG signature of an artifact.
-     * 
+     *
      * @param mainArtifact The artifact from which to derive the identity, must not be {@code null}.
      * @param classifier The classifier for this artifact, may be {@code null} if none.
      * @param extension The extension for this artifact, may be {@code null} if none.
      */
-    public SubArtifact( Artifact mainArtifact, String classifier, String extension )
-    {
-        this( mainArtifact, classifier, extension, (File) null );
+    public SubArtifact(Artifact mainArtifact, String classifier, String extension) {
+        this(mainArtifact, classifier, extension, (File) null);
     }
 
     /**
@@ -66,15 +62,14 @@ public final class SubArtifact
      * character "*" to refer to the corresponding property of the main artifact. For instance, the classifier
      * "*-sources" can be used to refer to the source attachment of an artifact. Likewise, the extension "*.asc" can be
      * used to refer to the GPG signature of an artifact.
-     * 
+     *
      * @param mainArtifact The artifact from which to derive the identity, must not be {@code null}.
      * @param classifier The classifier for this artifact, may be {@code null} if none.
      * @param extension The extension for this artifact, may be {@code null} if none.
      * @param file The file for this artifact, may be {@code null} if unresolved.
      */
-    public SubArtifact( Artifact mainArtifact, String classifier, String extension, File file )
-    {
-        this( mainArtifact, classifier, extension, null, file );
+    public SubArtifact(Artifact mainArtifact, String classifier, String extension, File file) {
+        this(mainArtifact, classifier, extension, null, file);
     }
 
     /**
@@ -82,15 +77,14 @@ public final class SubArtifact
      * character "*" to refer to the corresponding property of the main artifact. For instance, the classifier
      * "*-sources" can be used to refer to the source attachment of an artifact. Likewise, the extension "*.asc" can be
      * used to refer to the GPG signature of an artifact.
-     * 
+     *
      * @param mainArtifact The artifact from which to derive the identity, must not be {@code null}.
      * @param classifier The classifier for this artifact, may be {@code null} if none.
      * @param extension The extension for this artifact, may be {@code null} if none.
      * @param properties The properties of the artifact, may be {@code null}.
      */
-    public SubArtifact( Artifact mainArtifact, String classifier, String extension, Map<String, String> properties )
-    {
-        this( mainArtifact, classifier, extension, properties, null );
+    public SubArtifact(Artifact mainArtifact, String classifier, String extension, Map<String, String> properties) {
+        this(mainArtifact, classifier, extension, properties, null);
     }
 
     /**
@@ -98,26 +92,24 @@ public final class SubArtifact
      * character "*" to refer to the corresponding property of the main artifact. For instance, the classifier
      * "*-sources" can be used to refer to the source attachment of an artifact. Likewise, the extension "*.asc" can be
      * used to refer to the GPG signature of an artifact.
-     * 
+     *
      * @param mainArtifact The artifact from which to derive the identity, must not be {@code null}.
      * @param classifier The classifier for this artifact, may be {@code null} if none.
      * @param extension The extension for this artifact, may be {@code null} if none.
      * @param properties The properties of the artifact, may be {@code null}.
      * @param file The file for this artifact, may be {@code null} if unresolved.
      */
-    public SubArtifact( Artifact mainArtifact, String classifier, String extension, Map<String, String> properties,
-                        File file )
-    {
-        this.mainArtifact = requireNonNull( mainArtifact, "main artifact cannot be null" );
+    public SubArtifact(
+            Artifact mainArtifact, String classifier, String extension, Map<String, String> properties, File file) {
+        this.mainArtifact = requireNonNull(mainArtifact, "main artifact cannot be null");
         this.classifier = classifier;
         this.extension = extension;
         this.file = file;
-        this.properties = copyProperties( properties );
+        this.properties = copyProperties(properties);
     }
 
-    private SubArtifact( Artifact mainArtifact, String classifier, String extension, File file,
-                         Map<String, String> properties )
-    {
+    private SubArtifact(
+            Artifact mainArtifact, String classifier, String extension, File file, Map<String, String> properties) {
         // NOTE: This constructor assumes immutability of the provided properties, for internal use only
         this.mainArtifact = mainArtifact;
         this.classifier = classifier;
@@ -126,107 +118,84 @@ public final class SubArtifact
         this.properties = properties;
     }
 
-    public String getGroupId()
-    {
+    public String getGroupId() {
         return mainArtifact.getGroupId();
     }
 
-    public String getArtifactId()
-    {
+    public String getArtifactId() {
         return mainArtifact.getArtifactId();
     }
 
-    public String getVersion()
-    {
+    public String getVersion() {
         return mainArtifact.getVersion();
     }
 
-    public String getBaseVersion()
-    {
+    public String getBaseVersion() {
         return mainArtifact.getBaseVersion();
     }
 
-    public boolean isSnapshot()
-    {
+    public boolean isSnapshot() {
         return mainArtifact.isSnapshot();
     }
 
-    public String getClassifier()
-    {
-        return expand( classifier, mainArtifact.getClassifier() );
+    public String getClassifier() {
+        return expand(classifier, mainArtifact.getClassifier());
     }
 
-    public String getExtension()
-    {
-        return expand( extension, mainArtifact.getExtension() );
+    public String getExtension() {
+        return expand(extension, mainArtifact.getExtension());
     }
 
-    public File getFile()
-    {
+    public File getFile() {
         return file;
     }
 
-    public Artifact setFile( File file )
-    {
-        if ( Objects.equals( this.file, file ) )
-        {
+    public Artifact setFile(File file) {
+        if (Objects.equals(this.file, file)) {
             return this;
         }
-        return new SubArtifact( mainArtifact, classifier, extension, file, properties );
+        return new SubArtifact(mainArtifact, classifier, extension, file, properties);
     }
 
-    public Map<String, String> getProperties()
-    {
+    public Map<String, String> getProperties() {
         return properties;
     }
 
-    public Artifact setProperties( Map<String, String> properties )
-    {
-        if ( this.properties.equals( properties ) || ( properties == null && this.properties.isEmpty() ) )
-        {
+    public Artifact setProperties(Map<String, String> properties) {
+        if (this.properties.equals(properties) || (properties == null && this.properties.isEmpty())) {
             return this;
         }
-        return new SubArtifact( mainArtifact, classifier, extension, properties, file );
+        return new SubArtifact(mainArtifact, classifier, extension, properties, file);
     }
 
-    private static String expand( String pattern, String replacement )
-    {
+    private static String expand(String pattern, String replacement) {
         String result = "";
-        if ( pattern != null )
-        {
-            result = pattern.replace( "*", replacement );
+        if (pattern != null) {
+            result = pattern.replace("*", replacement);
 
-            if ( replacement.length() <= 0 )
-            {
-                if ( pattern.startsWith( "*" ) )
-                {
+            if (replacement.isEmpty()) {
+                if (pattern.startsWith("*")) {
                     int i = 0;
-                    for ( ; i < result.length(); i++ )
-                    {
-                        char c = result.charAt( i );
-                        if ( c != '-' && c != '.' )
-                        {
+                    for (; i < result.length(); i++) {
+                        char c = result.charAt(i);
+                        if (c != '-' && c != '.') {
                             break;
                         }
                     }
-                    result = result.substring( i );
+                    result = result.substring(i);
                 }
-                if ( pattern.endsWith( "*" ) )
-                {
+                if (pattern.endsWith("*")) {
                     int i = result.length() - 1;
-                    for ( ; i >= 0; i-- )
-                    {
-                        char c = result.charAt( i );
-                        if ( c != '-' && c != '.' )
-                        {
+                    for (; i >= 0; i--) {
+                        char c = result.charAt(i);
+                        if (c != '-' && c != '.') {
                             break;
                         }
                     }
-                    result = result.substring( 0, i + 1 );
+                    result = result.substring(0, i + 1);
                 }
             }
         }
         return result;
     }
-
 }
