@@ -20,7 +20,7 @@ package org.eclipse.aether.util.graph.selector;
 
 import org.junit.Test;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
 
 public class OptionalDependencySelectorTest {
     @Test
